<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="550px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="100px" >
        <el-form-item label="标题:" prop="title" >
          <el-input v-model.trim="state.form.title"></el-input>
        </el-form-item>
        <el-form-item prop="imgUrl" label="图片：">
          <el-upload accept="image/*" :action="state.uploadUrl" :headers="state.header" method="post" :on-success="(res, uploadFile)=>handleAvatarSuccess(res, uploadFile)" :on-exceed="showTip" :limit='state.imgLimit' v-model:file-list="state.imgList" list-type="picture-card" :before-upload="picSize" :on-remove="(file, uploadFiles)=>handleRemove(file, uploadFiles)" >
            <el-icon><Plus /></el-icon>
            <template #tip>
              <div class="el-upload__tip">上传jpg/png图片尺寸小于5M,最多可上传1张</div>
            </template>
          </el-upload>
        </el-form-item>
        <el-form-item label="地址:" prop="webUrl">
          <el-input v-model.trim="state.form.webUrl"></el-input>
        </el-form-item>
        <el-form-item label="跳转方式:" prop="carouselTarget" >
          <el-radio-group v-model="state.form.carouselTarget" >
            <el-radio :label="0">新窗口打开</el-radio>
            <el-radio :label="1">内部打开</el-radio>
          </el-radio-group>
        </el-form-item>
<!--        <el-form-item label="排序:" prop="sort" >-->
<!--          <el-input-number v-model="state.form.sort" />-->
<!--        </el-form-item>-->
        <el-form-item label="状态" prop="status" >
          <el-switch
              v-model="state.form.status"
              class="ml-2"
          />
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";
import {addNotice} from "@/api/backManage/notice";
import {addDict, editDict, getDictDetail} from "@/api/backManage/evaluate";
import {addCompany, checkName, distributeCompany, editCompany} from "@/api/onlineEducation/company";
import {verifyPhone} from "@/utils/validate";
import {addBanner, delPic, editBanner, getBannerById} from "@/api/onlineEducation/banner";
import {getToken} from "@/utils/auth";
import {getUserById} from "@/api/onlineEducation/user";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startUsername = ref('');
const startPhone = ref('');
const state = reactive({
  form: {
    id: '',
    title: '',
    imgUrl: '',
    webUrl: '',
    carouselTarget: 0,
    // sort: 0,
    status: true,
  },
  formRules:{
    title: [{ required: true, message: '请输入广告标题', trigger: 'blur' }],
    imgUrl: [{ required: true, message: '请上传图片', trigger: 'blur' }],
    webUrl: [{ required: true, message: '请输入地址', trigger: 'blur' }],
  },
  uploadUrl: import.meta.env.VITE_APP_BASE_API + '/system/common/uploadFile',
  header: {
    Authorization:getToken()
  },
  imgLimit: 1,
  imgList: []
})

const handleAvatarSuccess = (res, uploadFile) => {
  if(res.code == 200){
    state.form.imgUrl = res.data.path
  }else{
    state.imgList = []
    ElMessage({
      type: 'warning',
      message: '文件上传失败'
    })
  }
}
const showTip =()=>{
  ElMessage({
    type: 'warning',
    message: '超出文件上传数量'
  });
}
const picSize = async (rawFile) => {
  if(rawFile.size / 1024 / 1024 > 5){
    ElMessage({
      type: 'warning',
      message: '文件大小不能超过5M'
    });
    return false
  }
};
const handleRemove = async (file, uploadFiles) => {
  let path = state.form.imgUrl;
  await delPic({path: path}).then(res => {
    if(res.code == 200){
      // ElMessage({
      //   type: 'success',
      //   message: '文件已删除'
      // })
      state.form.imgUrl = ''
    }else{
      ElMessage({
        type: 'warning',
        message: res.message
      })
    }
  }).catch(() => {
    state.form.imgUrl = ''
  });
}

const openDialog = async (type, value) => {
  length.value = value.listLength
  title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '' ;
  if(type === 'edit') {
    const res = await getBannerById(value.id);
    if(res.code === 200){
      state.form = res.data
      console.log("11",res.data)
      state.form.carouselTarget = parseInt(res.data.carouselTarget)
      state.form.status = res.data.status == 0
      if(res.data.imgUrl) {
        const obj = {
          url: import.meta.env.VITE_APP_BASE_API + "/" +  res.data.imgUrl,
          name: ''
        }
        state.imgList = [obj]
      }
      console.log('imgList',state.imgList)
    }else{
      ElMessage.warning(res.message)
    }

  }
  dialogVisible.value = true;
}

const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      data.status = data.status ? 0 : 1
      const res = await addBanner(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      data.status = data.status ? 0 : 1
      const res = await editBanner(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const reset = () => {
  state.form = {
    id: '',
    title: '',
    imgUrl: '',
    webUrl: '',
    carouselTarget: 0,
    // sort: 0,
    status: true,
  }
  state.imgList = []
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
